#!/usr/bin/env python

"""Tests for pyani package command-line generation

These tests are intended to be run using the nose package
(see https://nose.readthedocs.org/en/latest/), from the repository root
directory.
"""


from nose.tools import assert_equal
from pyani import anim


# Test ANIm command-lines
# One pairwise comparison
def test_anim_pairwise_basic():
    """Test generation of basic NUCmer pairwise comparison command.
    """
    cmd = anim.construct_nucmer_cmdline("file1.fna", "file2.fna")
    assert_equal(cmd, "nucmer --mum -p ./nucmer_output/file1_vs_file2 " +
                 "file1.fna file2.fna; delta-filter -1 " +
                 "./nucmer_output/file1_vs_file2.delta > " +
                 "./nucmer_output/file1_vs_file2.filter")
    print(cmd)

def test_anim_pairwise_maxmatch():
    """Test generation of NUCmer pairwise comparison command with maxmatch.
    """
    cmd = anim.construct_nucmer_cmdline("file1.fna", "file2.fna",
                                        maxmatch=True)
    assert_equal(cmd, "nucmer --maxmatch -p ./nucmer_output/file1_vs_file2 " +
                 "file1.fna file2.fna; delta-filter -1 " +
                 "./nucmer_output/file1_vs_file2.delta > "
                 "./nucmer_output/file1_vs_file2.filter")    
    print(cmd)


# List of pairwise comparisons
def test_anim_collection():
    """Test generation of list of NUCmer comparison commands.
    """
    files = ["file1", "file2", "file3", "file4"]
    cmdlist = anim.generate_nucmer_commands(files)
    assert_equal(cmdlist, ['nucmer --mum -p ./nucmer_output/file1_vs_file2 ' +
                           'file1 file2; delta-filter -1 ' +
                           './nucmer_output/file1_vs_file2.delta > ' +
                           './nucmer_output/file1_vs_file2.filter',
                           'nucmer --mum -p ./nucmer_output/file1_vs_file3 ' +
                           'file1 file3; delta-filter -1 ' +
                           './nucmer_output/file1_vs_file3.delta > ' +
                           './nucmer_output/file1_vs_file3.filter',
                           'nucmer --mum -p ./nucmer_output/file1_vs_file4 ' +
                           'file1 file4; delta-filter -1 ' +
                           './nucmer_output/file1_vs_file4.delta > ' +
                           './nucmer_output/file1_vs_file4.filter',
                           'nucmer --mum -p ./nucmer_output/file2_vs_file3 ' +
                           'file2 file3; delta-filter -1 ' +
                           './nucmer_output/file2_vs_file3.delta > ' +
                           './nucmer_output/file2_vs_file3.filter',
                           'nucmer --mum -p ./nucmer_output/file2_vs_file4 ' +
                           'file2 file4; delta-filter -1 ' +
                           './nucmer_output/file2_vs_file4.delta > ' +
                           './nucmer_output/file2_vs_file4.filter',
                           'nucmer --mum -p ./nucmer_output/file3_vs_file4 ' +
                           'file3 file4; delta-filter -1 ' +
                           './nucmer_output/file3_vs_file4.delta > ' +
                           './nucmer_output/file3_vs_file4.filter'])    
    print(cmdlist)
